@@ -11,7 +11,8 @@ from parsley.decorators import parsleyfy
 from .forms import (TextForm, TextForm2, FieldTypeForm, ExtraDataForm,
         ExtraDataMissingFieldForm, FormWithWidgets, StudentModelForm,
         FormWithCleanField, FormWithCustomInit, FormWithCustomChoices,
-        FormWithMedia, FormWithoutMedia, MultiWidgetForm, CustomErrorMessageForm)
+        FormWithMedia, FormWithoutMedia, MultiWidgetForm, CustomErrorMessageForm,
+        CustomPrefixForm)
 from .models import Student
 from .admin import StudentAdmin
 
@@ -31,7 +32,7 @@ class ParsleyTestCase(TestCase):
 class CharFieldTest(ParsleyTestCase):
     def test_basic(self):
         """
-        Tests that parsleyfy will add data-required for required fields,
+        Tests that parsleyfy will add parsley-required for required fields,
         but not for required=False fields for CharFields
         """
         form = TextForm()
@@ -40,8 +41,8 @@ class CharFieldTest(ParsleyTestCase):
         ParsleyForm = parsleyfy(TextForm)
         form = ParsleyForm()
         self.assertAttrsEqual(form.fields["name"].widget.attrs, {
-            "data-required": "true",
-            "data-required-message": _("This field is required.")
+            "parsley-required": "true",
+            "parsley-required-message": _("This field is required.")
         })
         self.assertEqual(form.fields["university"].widget.attrs, {})
 
@@ -51,39 +52,39 @@ class CharFieldDecoratedTest(ParsleyTestCase):
         "Tests that parsleyfy works as a class Decorator"
         form = TextForm2()
         self.assertAttrsEqual(form.fields["name"].widget.attrs, {
-            "data-required": "true",
-            "data-required-message": _("This field is required.")
+            "parsley-required": "true",
+            "parsley-required-message": _("This field is required.")
         })
         self.assertEqual(form.fields["university"].widget.attrs, {})
 
 
 class FieldTypeFormTest(ParsleyTestCase):
     def test_fields(self):
-        "Tests that parsleyfy adds data-required for things other than CharField"
+        "Tests that parsleyfy adds parsley-required for things other than CharField"
         form = FieldTypeForm()
         fields = form.fields
-        self.assertEqual(fields["url"].widget.attrs["data-required"], "true")
-        self.assertFalse("data-required" in fields["url2"].widget.attrs)
-        self.assertEqual(fields["email"].widget.attrs["data-required"], "true")
-        self.assertFalse("data-required" in fields["email2"].widget.attrs)
+        self.assertEqual(fields["url"].widget.attrs["parsley-required"], "true")
+        self.assertFalse("parsley-required" in fields["url2"].widget.attrs)
+        self.assertEqual(fields["email"].widget.attrs["parsley-required"], "true")
+        self.assertFalse("parsley-required" in fields["email2"].widget.attrs)
 
 
 class DataTypeTest(ParsleyTestCase):
     def test_data_types(self):
-        "Test that different field types get correct data-type"
+        "Test that different field types get correct parsley-type"
         form = FieldTypeForm()
         fields = form.fields
-        self.assertTrue("data-type" in fields["url"].widget.attrs)
-        self.assertEqual(fields["url"].widget.attrs["data-type"], "url")
-        self.assertTrue("data-type" in fields["email"].widget.attrs)
-        self.assertEqual(fields["email"].widget.attrs["data-type"], "email")
-        self.assertEqual(fields["age"].widget.attrs["data-type"], "digits")
-        self.assertEqual(fields["income"].widget.attrs["data-type"], "number")
-        self.assertEqual(fields["income2"].widget.attrs["data-type"], "number")
-        self.assertEqual(fields["topnav"].widget.attrs["data-regexp"], "#[A-Fa-f0-9]{6}")
-        self.assertNotIn("data-regexp-flag", fields["topnav"].widget.attrs)
-        self.assertEqual(fields["topnav2"].widget.attrs["data-regexp"], "#[a-z]+")
-        self.assertEqual(fields["topnav2"].widget.attrs["data-regexp-flag"], "i")
+        self.assertTrue("parsley-type" in fields["url"].widget.attrs)
+        self.assertEqual(fields["url"].widget.attrs["parsley-type"], "url")
+        self.assertTrue("parsley-type" in fields["email"].widget.attrs)
+        self.assertEqual(fields["email"].widget.attrs["parsley-type"], "email")
+        self.assertEqual(fields["age"].widget.attrs["parsley-type"], "digits")
+        self.assertEqual(fields["income"].widget.attrs["parsley-type"], "number")
+        self.assertEqual(fields["income2"].widget.attrs["parsley-type"], "number")
+        self.assertEqual(fields["topnav"].widget.attrs["parsley-regexp"], "#[A-Fa-f0-9]{6}")
+        self.assertNotIn("parsley-regexp-flag", fields["topnav"].widget.attrs)
+        self.assertEqual(fields["topnav2"].widget.attrs["parsley-regexp"], "#[a-z]+")
+        self.assertEqual(fields["topnav2"].widget.attrs["parsley-regexp-flag"], "i")
 
 
 class LengthTest(ParsleyTestCase):
@@ -91,9 +92,9 @@ class LengthTest(ParsleyTestCase):
         form = FieldTypeForm()
         fields = form.fields
         name_attrs = fields["name"].widget.attrs
-        self.assertTrue("data-minlength" in name_attrs)
-        self.assertEqual(name_attrs["data-minlength"], 3)
-        self.assertEqual(name_attrs["data-maxlength"], 30)
+        self.assertTrue("parsley-minlength" in name_attrs)
+        self.assertEqual(name_attrs["parsley-minlength"], 3)
+        self.assertEqual(name_attrs["parsley-maxlength"], 30)
 
 
 class ValueTest(ParsleyTestCase):
@@ -101,10 +102,10 @@ class ValueTest(ParsleyTestCase):
         form = FieldTypeForm()
         fields = form.fields
         num_attrs = fields['some_num'].widget.attrs
-        self.assertTrue("data-min" in num_attrs, True)
-        self.assertTrue("data-max" in num_attrs, True)
-        self.assertEqual(num_attrs["data-min"], 10)
-        self.assertEqual(num_attrs["data-max"], 100)
+        self.assertTrue("parsley-min" in num_attrs, True)
+        self.assertTrue("parsley-max" in num_attrs, True)
+        self.assertEqual(num_attrs["parsley-min"], 10)
+        self.assertEqual(num_attrs["parsley-max"], 100)
 
 
 class FormWithWidgetsTest(ParsleyTestCase):
@@ -137,7 +138,7 @@ class TestModelForm(ParsleyTestCase):
         form = StudentModelForm()
         fields = form.fields
         foo_attrs = fields["name"].widget.attrs
-        self.assertEqual(foo_attrs["data-required"], "true")
+        self.assertEqual(foo_attrs["parsley-required"], "true")
 
     def test_model_form_save(self):
         form = StudentModelForm({"name": "Luke Skywalker"})
@@ -175,29 +176,29 @@ class TestExtraAttributes(ParsleyTestCase):
         form = ExtraDataForm()
         attrs = form.fields["email2"].widget.attrs
         self.assertAttrsEqual(attrs, {
-            "data-type": "email",
-            "data-required": "true",
-            "data-equalto-message": "Must match",
-            "data-equalto": "#id_email",
-            "data-required-message": _("This field is required."),
+            "parsley-type": "email",
+            "parsley-required": "true",
+            "parsley-equalto-message": "Must match",
+            "parsley-equalto": "#id_email",
+            "parsley-required-message": _("This field is required."),
         })
 
     def test_default_data(self):
         form = ExtraDataForm()
         attrs = form.fields["name"].widget.attrs
         self.assertAttrsEqual(attrs, {
-            "data-required": "true",
-            "data-error-message": "Name invalid",
-            "data-required-message": _("This field is required.")
+            "parsley-required": "true",
+            "parsley-error-message": "Name invalid",
+            "parsley-required-message": _("This field is required.")
         })
 
     def test_boolean_values(self):
         form = ExtraDataForm()
         attrs = form.fields["hide_errors"].widget.attrs
         self.assertAttrsEqual(attrs, {
-            "data-required": "true",
-            "data-show-errors": "false",
-            "data-required-message": _("This field is required.")
+            "parsley-required": "true",
+            "parsley-show-errors": "false",
+            "parsley-required-message": _("This field is required.")
         })
 
     def test_missing_field(self):
@@ -209,7 +210,7 @@ class TestAdminMixin(ParsleyTestCase):
         student_admin = StudentAdmin(Student, admin.site)
         js = student_admin.media.render_js()
         self.assertIn(
-            '<script type="text/javascript" src="/static/parsley/js/parsley-standalone.min.js"></script>',
+            '<script type="text/javascript" src="/static/parsley/js/parsley.min.js"></script>',
             js
         )
         self.assertIn(
@@ -224,7 +225,7 @@ class TestFormMedia(ParsleyTestCase):
         form = FormWithoutMedia()
         js = form.media.render_js()
         self.assertIn(
-            '<script type="text/javascript" src="/static/parsley/js/parsley-standalone.min.js"></script>',
+            '<script type="text/javascript" src="/static/parsley/js/parsley.min.js"></script>',
             js
         )
 
@@ -236,7 +237,7 @@ class TestFormMedia(ParsleyTestCase):
             js
         )
         self.assertIn(
-            '<script type="text/javascript" src="/static/parsley/js/parsley-standalone.min.js"></script>',
+            '<script type="text/javascript" src="/static/parsley/js/parsley.min.js"></script>',
             js
         )
 
@@ -246,22 +247,22 @@ class TestMultiValueField(ParsleyTestCase):
         form = MultiWidgetForm()
         fields = form.fields["ssn"].fields
         self.assertAttrsEqual(fields[0].widget.attrs, {
-            "data-minlength": 3,
-            "data-maxlength": 3,
+            "parsley-minlength": 3,
+            "parsley-maxlength": 3,
             "maxlength": "3",
-            "data-regexp": r'^(\d)+$',
+            "parsley-regexp": r'^(\d)+$',
         })
         self.assertAttrsEqual(fields[1].widget.attrs, {
-            "data-minlength": 3,
-            "data-maxlength": 3,
+            "parsley-minlength": 3,
+            "parsley-maxlength": 3,
             "maxlength": "3",
-            "data-regexp": r'^(\d)+$',
+            "parsley-regexp": r'^(\d)+$',
         })
         self.assertAttrsEqual(fields[2].widget.attrs, {
-            "data-minlength": 4,
-            "data-maxlength": 4,
+            "parsley-minlength": 4,
+            "parsley-maxlength": 4,
             "maxlength": "4",
-            "data-regexp": r'^(\d)+$',
+            "parsley-regexp": r'^(\d)+$',
         })
 
 
@@ -272,22 +273,34 @@ class TestCustomErrorMessages(TestCase):
         attrs = form.fields['name'].widget.attrs
         self.assertEqual(attrs, {
             "maxlength": '30',
-            "data-maxlength": 30,
-            "data-maxlength-message": "Please only 30 characters"
+            "parsley-maxlength": 30,
+            "parsley-maxlength-message": "Please only 30 characters"
         })
 
     def test_field_type_message(self):
         form = CustomErrorMessageForm()
         attrs = form.fields['email'].widget.attrs
         self.assertEqual(attrs, {
-            "data-type": "email",
-            "data-type-email-message": "Invalid email"
+            "parsley-type": "email",
+            "parsley-type-email-message": "Invalid email"
         })
 
     def test_override_default_message(self):
         form = CustomErrorMessageForm()
         attrs = form.fields['favorite_color'].widget.attrs
         self.assertEqual(attrs, {
-            "data-required": "true",
-            "data-required-message": "Favorite color is required"
+            "parsley-required": "true",
+            "parsley-required-message": "Favorite color is required"
         })
+
+class TestCustomPrefix(TestCase):
+
+    def test_default_prefix(self):
+        form = TextForm()
+        attrs = form.fields['name'].widget.attrs
+        self.assertTrue('parsley-required' in attrs)
+
+    def test_custom_prefix(self):
+        form = CustomPrefixForm()
+        attrs = form.fields['name'].widget.attrs
+        self.assertTrue('custom-required' in attrs)
